@@ -1,5 +1,6 @@
 #!/bin/sh
 
+UTILDIR=~/devel/gnome-app-install/checkout/main/util
 TOPDIR=./
 TARGETDIR=./menu-data/
 MENU=menu-data-$(date +%Y%m%d).tar.gz
@@ -19,10 +20,11 @@ bzr add $TARGETDIR/*.desktop
 bzr add $TARGETDIR/icons/*
 
 # update the codec information based on the Packages file output
-../main/util/gst-add.py ./menu-data-codecs/*.desktop
+$UTILDIR/gst-add.py ./menu-data-codecs/*.desktop
 
-../main/util/addPopconData.py -d ./menu-data
-../main/util/addPopconData.py -d ./menu-data-additional
-../main/util/addPopconData.py -d ./menu-data-firefox
-../main/util/addPopconData.py -d ./menu-data-codecs
+$UTILDIR/addPopconData.py -d ./menu-data
+$UTILDIR/addPopconData.py -d ./menu-data-additional
+$UTILDIR/addPopconData.py -d ./menu-data-xul-extensions
+$UTILDIR/addPopconData.py -d ./menu-data-codecs
+$UTILDIR/addPopconData.py -d ./menu-data-edubuntu
 
